summaryrefslogtreecommitdiff
path: root/src/mongo/bson/util/builder.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/mongo/bson/util/builder.h')
-rw-r--r--src/mongo/bson/util/builder.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/src/mongo/bson/util/builder.h b/src/mongo/bson/util/builder.h
index 64b578faafd..4d66fdee83e 100644
--- a/src/mongo/bson/util/builder.h
+++ b/src/mongo/bson/util/builder.h
@@ -273,15 +273,16 @@ public:
str.copyTo(grow(len), includeEndingNull);
}
- /** @return length of current std::string */
+ /** Returns the length of data in the current buffer */
int len() const {
return l;
}
void setlen(int newLen) {
l = newLen;
}
- /** @return size of the buffer */
- int getSize() const {
+
+ /** Returns the capacity of the buffer */
+ int capacity() const {
return size;
}